# pySPADS
**pySPADS** is an implementation of the "Shoreline Prediction at Different Time-Scales" (SPADS) algorithm developed in the paper ["A Multiscale Approach to Shoreline Prediction" by Montano et. al. (2020).](https://agupubs.onlinelibrary.wiley.com/doi/10.1029/2020GL090587)

## Work-in-progress
This package is functionally complete, and contains all the logic necessary to run the SPADS analysis. 
However, the documentation, CLI and more usage examples are still a work in progress.

The most useful resources for understanding how to use the package are the [example scripts](https://github.com/UoA-eResearch/pySPADS/tree/main/scripts), along with the [example data](https://github.com/UoA-eResearch/pySPADS/tree/main/data/example_run) in the project repository. 